[Libreoffice-commits] core.git: filter/qa qadevOOo/runner qadevOOo/tests

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Tue May 28 14:48:59 UTC 2019


 filter/qa/complex/filter/misc/FinalizedMandatoryTest.java    |    8 +-
 qadevOOo/runner/util/dbg.java                                |   12 +--
 qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java       |   12 +--
 qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java          |    2 
 qadevOOo/tests/java/ifc/beans/_XPropertyContainer.java       |    4 -
 qadevOOo/tests/java/ifc/frame/_XModuleManager.java           |   34 +++++------
 qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java |    2 
 qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java |    2 
 8 files changed, 38 insertions(+), 38 deletions(-)

New commits:
commit f1f2e2823749452d8e7f23891876e5cc10000553
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Mon May 27 13:32:13 2019 +0000
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue May 28 16:48:09 2019 +0200

    Fix typos (including sequenze->sequence)
    
    Change-Id: Icfd6c5cbc405bad51a0d7f10cdb55c70a1fe5b00
    Reviewed-on: https://gerrit.libreoffice.org/73078
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Jenkins

diff --git a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
index 2334f2c1c83b..d9fb68e6e0b8 100644
--- a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
+++ b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
@@ -232,7 +232,7 @@ public class FinalizedMandatoryTest
      * print all properties with its values to <CODE>logger</CODE>. For debug purposes.
      * @see stats.SimpleLogWriter
      * @see com.sun.star.beans.PropertyValue
-     * @param props Sequenze of PropertyValue
+     * @param props Sequence of PropertyValue
      */
     protected void printPropertyValues(PropertyValue[] props)
     {
@@ -249,7 +249,7 @@ public class FinalizedMandatoryTest
     }
 
     /**
-     * returns the value of the specified (<CODE>pName</CODE>) property from a sequenze of <CODE>PropertyValue</CODE>
+     * returns the value of the specified (<CODE>pName</CODE>) property from a sequence of <CODE>PropertyValue</CODE>
      * @param props a sequence of <CODE>PropertyValue</CODE>
      * @param pName the name of the property the value should be returned
      * @return the value of the property
@@ -265,8 +265,8 @@ public class FinalizedMandatoryTest
     }
 
     /**
-     * set a value of the specified (<CODE>pName</CODE>) property inside a sequenze of <CODE>PropertyValue</CODE>
-     * @param props sequenze of <CODE>PropertyValue</CODE>
+     * set a value of the specified (<CODE>pName</CODE>) property inside a sequence of <CODE>PropertyValue</CODE>
+     * @param props sequence of <CODE>PropertyValue</CODE>
      * @param pName name of the property which should be changed
      * @param pValue the value the property should be assigned
      */
diff --git a/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java b/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java
index daf791ede429..9dcb8cca585f 100644
--- a/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java
+++ b/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java
@@ -70,8 +70,8 @@ public class _XUnoControlContainer extends MultiMethodTest {
     /**
     * This tests removes the object relations <code>TABCONTROL1</code> and
     * <code>TABCONTROL1</code>.
-    * Has <b> OK </b> status if the sequenze of <code>XTabController[]</code>
-    * get before calling method is smaller then sequenze of
+    * Has <b> OK </b> status if the sequence of <code>XTabController[]</code>
+    * get before calling method is smaller then sequence of
     * <code>XTabController[]</code> get after calling method.<p>
     *
     * The following method tests are to be completed successfully before :
@@ -119,8 +119,8 @@ public class _XUnoControlContainer extends MultiMethodTest {
 
     /**
     * Test calls the method with object relation 'TABCONTROL1' as a parameter.<p>
-    * Has <b> OK </b> status if the sequenze of <code>XTabController[]</code>
-    * get before calling method is smaller then sequenze of
+    * Has <b> OK </b> status if the sequence of <code>XTabController[]</code>
+    * get before calling method is smaller then sequence of
     * <code>XTabController[]</code> get after calling method.<p>
     */
     public void _addTabController() {
@@ -139,8 +139,8 @@ public class _XUnoControlContainer extends MultiMethodTest {
 
     /**
     * Test calls the method with object relation 'TABCONTROL2' as a parameter.<p>
-    * Has <b> OK </b> status if the sequenze of <code>XTabController[]</code>
-    * get before calling method is smaller then sequenze of
+    * Has <b> OK </b> status if the sequence of <code>XTabController[]</code>
+    * get before calling method is smaller then sequence of
     * <code>XTabController[]</code> get after calling method.<p>
     *
     * The following method tests are to be completed successfully before :
diff --git a/qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java b/qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java
index 10c26002e58e..697290dc7386 100644
--- a/qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java
+++ b/qadevOOo/tests/java/ifc/beans/_XPropertyAccess.java
@@ -64,7 +64,7 @@ public class _XPropertyAccess extends MultiMethodTest {
     }
 
     /**
-     * Test calls the method and checks if the returned sequenze contanis a propterty which is named
+     * Test calls the method and checks if the returned sequence contains a property which is named
      * in the object relation <code>XPropertyAccess.propertyToChange</code>.
      */
     public void _getPropertyValues() {
diff --git a/qadevOOo/tests/java/ifc/beans/_XPropertyContainer.java b/qadevOOo/tests/java/ifc/beans/_XPropertyContainer.java
index ec590a1e163d..00fcff66f09f 100644
--- a/qadevOOo/tests/java/ifc/beans/_XPropertyContainer.java
+++ b/qadevOOo/tests/java/ifc/beans/_XPropertyContainer.java
@@ -66,7 +66,7 @@ public class _XPropertyContainer extends MultiMethodTest {
 
 
     /**
-     * Test calls the method and checks if the returned sequence contanis a propterty which is named
+     * Test calls the method and checks if the returned sequence contains a property which is named
      * in the object relation <code>XPropertyAccess.propertyNotRemovable</code>.
      */
     public void _addProperty() {
@@ -214,7 +214,7 @@ public class _XPropertyContainer extends MultiMethodTest {
     }
 
     /**
-     * Test calls the method and checks if the returned sequence contanis a propterty which is named
+     * Test calls the method and checks if the returned sequence contains a property which is named
      * in the object relation <code>XPropertyAccess.propertyNotRemovable</code>.
      */
     public void _removeProperty() {
diff --git a/qadevOOo/tests/java/ifc/frame/_XModuleManager.java b/qadevOOo/tests/java/ifc/frame/_XModuleManager.java
index 9ff0587f66f6..dcca39d7162c 100644
--- a/qadevOOo/tests/java/ifc/frame/_XModuleManager.java
+++ b/qadevOOo/tests/java/ifc/frame/_XModuleManager.java
@@ -105,12 +105,12 @@ public class _XModuleManager extends MultiMethodTest {
      */
     public void _identify() {
         boolean ok = true;
-        log.println("testing frame sequenze...");
-        ok &= testSequenze(xFrameSeq);
-        log.println("testing controller sequenze...");
-        ok &= testSequenze(xControllerSeq);
-        log.println("testing model sequenze...");
-        ok &= testSequenze(xModelSeq);
+        log.println("testing frame sequence...");
+        ok &= testSequence(xFrameSeq);
+        log.println("testing controller sequence...");
+        ok &= testSequence(xControllerSeq);
+        log.println("testing model sequence...");
+        ok &= testSequence(xModelSeq);
         tRes.tested("identify()", ok);
 
         log.println("testing invalid objects...");
@@ -123,26 +123,26 @@ public class _XModuleManager extends MultiMethodTest {
         }
     }
 
-    private boolean testSequenze(PropertyValue[] sequenze){
+    private boolean testSequence(PropertyValue[] sequence){
         boolean ok = true;
-        for (int i = 0 ; i < sequenze.length; i++){
+        for (int i = 0 ; i < sequence.length; i++){
             try{
-                log.println("testing '" + sequenze[i].Name + "'");
-                if (!oObj.identify(sequenze[i].Value).equals(
-                                                        sequenze[i].Name)) {
+                log.println("testing '" + sequence[i].Name + "'");
+                if (!oObj.identify(sequence[i].Value).equals(
+                                                        sequence[i].Name)) {
                      log.println("failure: returned value: '" +
-                                 oObj.identify(sequenze[i].Value) +
-                                 "' ,expected value: '" + sequenze[i].Name + "'");
+                                 oObj.identify(sequence[i].Value) +
+                                 "' ,expected value: '" + sequence[i].Name + "'");
                      ok = false;
                 }
             } catch (IllegalArgumentException e){
-                log.println("Could not get value of sequenze '" +
-                            sequenze[i].Name + "'");
+                log.println("Could not get value of sequence '" +
+                            sequence[i].Name + "'");
                 return false;
 
             } catch (UnknownModuleException e){
-                log.println("Could not indetify value of sequenze '" +
-                            sequenze[i].Name + "'");
+                log.println("Could not indetify value of sequence '" +
+                            sequence[i].Name + "'");
                 return false;
             }
         }
diff --git a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
index ff422b059896..5c8ee67f7951 100644
--- a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
+++ b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryAnalyzer.java
@@ -134,7 +134,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
     /**
     * Object relation <code>xComposer</code> set a complex filter with method
     . <code>setFilter</code>. Then <code>getStructuredFilter</code> returns a
-    * sequenze of <code>PropertyValue</code> which was set with method
+    * sequence of <code>PropertyValue</code> which was set with method
     * <code>setStructuredFilter</code> from <xComposer>.
     * Then test has ok status if <getFilter> returns the complex filter.
     * <p>
diff --git a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java
index b34cb98e73bf..53b31f6931f5 100644
--- a/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java
+++ b/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java
@@ -139,7 +139,7 @@ public class _XSingleSelectQueryComposer extends MultiMethodTest {
     /**
     * Object relation <code>xQueryAna</code> set a complex filter with method
     . <code>setFilter</code>. Then <code>getStructuredFilter</code> returns a
-    * sequenze of <code>PropertyValue</code> which was set with method
+    * sequence of <code>PropertyValue</code> which was set with method
     * <code>setStructuredFilter</code> from <code>xQueryAna</code>.
     * Then test has ok status if <code>getFilter</code> returns the complex filter.
     */


More information about the Libreoffice-commits mailing list
diff --git a/qadevOOo/runner/util/dbg.java b/qadevOOo/runner/util/dbg.java
index 3a0035cde079..5416e92f6d58 100644
--- a/qadevOOo/runner/util/dbg.java
+++ b/qadevOOo/runner/util/dbg.java
@@ -186,15 +186,15 @@ public class dbg {
 
 
     /**
      * Print the names and the values of a sequenze of <code>PropertyValue</code>
      * to a print writer.
      * @param ps The property which should displayed
      * @param out The print writer which is used as output.
      * @see com.sun.star.beans.PropertyValue
      */
-    private static void printProperyValueSequenzePairs(PropertyValue[] ps, PrintWriter out){
+    private static void printPropertyValueSequencePairs(PropertyValue[] ps, PrintWriter out){
         for( int i = 0; i < ps.length; i++){
-            printProperyValuePairs(ps[i], out);
+            printPropertyValuePairs(ps[i], out);
         }
     }
 
@@ -206,7 +206,7 @@ public class dbg {
      * @param out The print writer which is used as output.
      * @see com.sun.star.beans.PropertyValue
      */
-    private static void printProperyValuePairs(PropertyValue ps, PrintWriter out){
+    private static void printPropertyValuePairs(PropertyValue ps, PrintWriter out){
 
         if (ps.Value instanceof String[] ){
             String[] values = (String[]) ps.Value;
@@ -227,13 +227,13 @@ public class dbg {
         } else if (ps.Value instanceof PropertyValue){
             out.println("--------");
             out.println("   Name: '" + ps.Name + "' contains PropertyValue:");
-            printProperyValuePairs((PropertyValue)ps.Value, out);
+            printPropertyValuePairs((PropertyValue)ps.Value, out);
             out.println("--------");
 
         } else if (ps.Value instanceof PropertyValue[]){
             out.println("--------");
             out.println("   Name: '" + ps.Name + "' contains PropertyValue[]:");
-            printProperyValueSequenzePairs((PropertyValue[])ps.Value, out);
+            printPropertyValueSequencePairs((PropertyValue[])ps.Value, out);
             out.println("--------");
 
         } else {
@@ -186,15 +186,15 @@ public class dbg {
 
     /**
-     * Print the names and the values of a sequenze of <code>PropertyValue</code>
+     * Print the names and the values of a sequence of <code>PropertyValue</code>
      * to a print writer.
      * @param ps The property which should displayed